@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2015 The Music Player Daemon Project
+   (c) 2003-2018 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,8 @@
 #include <mpd/async.h>
 #include <mpd/parser.h>
 #include <mpd/password.h>
+#include <mpd/socket.h>
+
 #include "resolver.h"
 #include "sync.h"
 #include "socket.h"
@@ -112,7 +114,7 @@ mpd_connection_new(const char *host, unsigned port, unsigned timeout_ms)
 	connection->settings = settings;
 
 	bool success;
-	int fd;
+	mpd_socket_t fd;
 	const char *line;
 
 	mpd_error_init(&connection->error);
@@ -132,7 +134,7 @@ mpd_connection_new(const char *host, unsigned port, unsigned timeout_ms)
 	host = mpd_settings_get_host(settings);
 	fd = mpd_socket_connect(host, mpd_settings_get_port(settings),
 				&connection->timeout, &connection->error);
-	if (fd < 0) {
+	if (fd == MPD_INVALID_SOCKET) {
 #if defined(DEFAULT_SOCKET) && defined(ENABLE_TCP)
 		if (host == NULL || strcmp(host, DEFAULT_SOCKET) == 0) {
 			/* special case: try the default host if the
@@ -149,7 +151,7 @@ mpd_connection_new(const char *host, unsigned port, unsigned timeout_ms)
 		}
 #endif
 
-		if (fd < 0)
+		if (fd == MPD_INVALID_SOCKET)
 			return connection;
 	}
 
@@ -195,6 +197,7 @@ mpd_connection_new_async(struct mpd_async *async, const char *welcome)
 		return NULL;
 
 	mpd_error_init(&connection->error);
+	connection->settings = NULL;
 	connection->async = async;
 	connection->timeout.tv_sec = 30;
 	connection->timeout.tv_usec = 0;
@@ -240,7 +243,7 @@ void mpd_connection_free(struct mpd_connection *connection)
 
 void
 mpd_connection_set_keepalive(struct mpd_connection *connection,
-                             bool keepalive)
+			     bool keepalive)
 {
 	assert(connection != NULL);
 
