@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2015 The Music Player Daemon Project
+   (c) 2003-2018 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -57,6 +57,18 @@ bool
 mpd_send_float_command(struct mpd_connection *connection, const char *command,
 		       float arg);
 
+bool
+mpd_send_u_f_command(struct mpd_connection *connection, const char *command,
+		     unsigned arg1, float arg2);
+
+bool
+mpd_send_u_s_command(struct mpd_connection *connection, const char *command,
+		     unsigned arg1, const char *arg2);
+
+bool
+mpd_send_u_s_s_command(struct mpd_connection *connection, const char *command,
+		       unsigned arg1, const char *arg2, const char *arg3);
+
 bool
 mpd_send_s_u_command(struct mpd_connection *connection, const char *command,
 		     const char *arg1, unsigned arg2);
@@ -65,6 +77,14 @@ bool
 mpd_send_range_command(struct mpd_connection *connection, const char *command,
 		       unsigned arg1, unsigned arg2);
 
+/**
+ * Send command with one string argument followed by a range argument.
+ */
+bool
+mpd_send_s_range_command(struct mpd_connection *connection,
+			 const char *command, const char *arg1,
+			 unsigned start, unsigned end);
+
 /**
  * Send command with one integer argument followed by a range argument.
  */
@@ -73,6 +93,11 @@ mpd_send_i_range_command(struct mpd_connection *connection,
 			 const char *command, int arg1,
 			 unsigned start, unsigned end);
 
+bool
+mpd_send_u_range_command(struct mpd_connection *connection,
+			 const char *command, unsigned arg1,
+			 unsigned start, unsigned end);
+
 bool
 mpd_send_range_u_command(struct mpd_connection *connection,
 			 const char *command,
