@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2017 The Music Player Daemon Project
+   (c) 2003-2018 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ enum {
 static void
 format_range(char *buffer, size_t size, unsigned start, unsigned end)
 {
-	if (end == (unsigned)-1)
+	if (end == UINT_MAX)
 		/* the special value -1 means "open end" */
 		snprintf(buffer, size, "%u:", start);
 	else
@@ -229,6 +229,18 @@ mpd_send_range_command(struct mpd_connection *connection, const char *command,
 	return mpd_send_command(connection, command, arg_string, NULL);
 }
 
+bool
+mpd_send_s_range_command(struct mpd_connection *connection,
+			 const char *command, const char *arg1,
+			 unsigned start, unsigned end)
+{
+	char range_string[INTLEN * 2 + 1];
+
+	format_range(range_string, sizeof(range_string), start, end);
+	return mpd_send_command(connection, command,
+				arg1, range_string, NULL);
+}
+
 bool
 mpd_send_i_range_command(struct mpd_connection *connection,
 			 const char *command, int arg1,
