@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2017 The Music Player Daemon Project
+   (c) 2003-2018 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -33,7 +33,7 @@
 
 #include <stdbool.h>
 
-#ifdef WIN32
+#ifdef _WIN32
 #  include <winsock2.h>
 #else
 #  include <errno.h>
@@ -42,7 +42,7 @@
 struct timeval;
 struct mpd_error_info;
 
-#ifdef WIN32
+#ifdef _WIN32
 bool
 mpd_socket_global_init(struct mpd_error_info *error);
 #else
@@ -57,13 +57,26 @@ mpd_socket_global_init(struct mpd_error_info *error)
 static inline int
 mpd_socket_errno(void)
 {
-#ifdef WIN32
+#ifdef _WIN32
 	return WSAGetLastError();
 #else
 	return errno;
 #endif
 }
 
+/**
+ * Can this error code be ignored?
+ */
+static inline bool
+mpd_socket_ignore_errno(int e)
+{
+#ifdef _WIN32
+	return e == WSAEINTR || e == WSAEINPROGRESS || e == WSAEWOULDBLOCK;
+#else
+	return e == EINTR || e == EINPROGRESS || e == EAGAIN;
+#endif
+}
+
 /**
  * Connects the socket to the specified host and port.
  *
@@ -78,12 +91,12 @@ mpd_socket_connect(const char *host, unsigned port, const struct timeval *tv,
  * closesocket(), depending on the OS.
  */
 int
-mpd_socket_close(int fd);
+mpd_socket_close(mpd_socket_t fd);
 
 /**
  * Sets (or unsets) keepalive on a socket descriptor.
  */
 void
-mpd_socket_keepalive(int fd, bool keepalive);
+mpd_socket_keepalive(mpd_socket_t fd, bool keepalive);
 
 #endif
